## automatically print usage when sourcing this file
usage() {
    grep '^#/' "$0" | cut -c4-
    exit 0
}
expr "$*" : ".*--help" > /dev/null && usage

## print to stderror
eprint() {
    echo "$@" >&2
}

## print error message and exit
die() {
    eprint "$@"
    exit 1
}

# get environment variable named after the passed string
getvar() {
    echo ${!1}
}

cd_root() {
    unset CDPATH
    cd "$ZET_ROOT"
}

## filter converting string to lower/upper case
tolower() {
    awk '{print tolower($0)}'
}

toupper() {
    awk '{print toupper($0)}'
}

## filter notebook name, changing it to the form which is acceptable by
## environment variables

name_to_env() {
    echo "$1" | toupper | sed 's/ /_/g'
}

## strip string from the left side of the other string
strip() {
    source="$1"
    stripped="$2"
    echo "${source##$stripped}"
}

## get notebook path by its alias (name). Comparison is case-insensitive
getipath() {
    name="$(echo "$1" | tolower)"
    test -z "$name" && return 1

    while read -d ':' notebook; do
        nbname="$(getvar "ZET_NOTEBOOK_${notebook}_NAME" | tolower)"
        if [[ "$nbname" == "$name" ]]; then
            echo "$(getvar "ZET_NOTEBOOK_${notebook}_PATH")"
            return 0
        fi
    done <<< "$ZET_NOTEBOOKS:"

    return 1
}

## get notebook paths
notebooks_paths() {
    while read -d ':' notebook; do
        echo "$(getvar "ZET_NOTEBOOK_${notebook}_PATH")"
    done <<< "$ZET_NOTEBOOKS:"
}

## list files in a notebook
list_files() {
    notebook="$1"
    test -z "$notebook" && return 1
    find "$notebook" -type f ! -path '*/.*/*' | sed 's,^.\/,,g'
}

command_exists() {
    hash "$1" 2>/dev/null
}

is_notebook() {
    notebook=$(name_to_env "$1")
    path="$(getvar "ZET_NOTEBOOK_${notebook}_PATH")"
    test -n "$path"
}

default_notebook() {
    default_file="${ZET_ROOT}/.default-notebook"
    if [[ -e "$default_file" ]]; then
        nb=$(head -n 1 "$default_file" | tr -d ' ')
        if $(is_notebook "$nb"); then
            echo "$nb"
            return 0
        else
            eprint ".default-notebook: not a notebook: '$nb'"
        fi
    fi
    echo "$ZET_NOTEBOOKS" | awk -F ":" '{ print $1 }'
}
